@@ -57,7 +57,8 @@ sub new {
         if !$binary{$git};
 
     # get some useful paths
-    my ( $repo_path, $wc_path ) = ( $r->repo_path, $r->wc_path)
+    my ( $repo_path, $wc_path, $wc_subdir )
+        = ( $r->repo_path, $r->wc_path, $r->wc_subdir )
         if $r;
 
     # setup %ENV (no blocks to preserve local)
@@ -69,9 +70,10 @@ sub new {
     # chdir to the expected directory
     my $orig = cwd;
     my $dest
-        = defined $o->{cwd}                   ? $o->{cwd}
-        : defined $wc_path && length $wc_path ? $wc_path
-        :                                       undef;
+        = defined $o->{cwd}                       ? $o->{cwd}
+        : defined $wc_subdir && length $wc_subdir ? $wc_subdir
+        : defined $wc_path   && length $wc_path   ? $wc_path
+        :                                           undef;
     if ( defined $dest ) {
         chdir $dest or croak "Can't chdir to $dest: $!";
     }
